@@ -11,15 +11,30 @@ from rich.progress import Progress, SpinnerColumn, TextColumn, MofNCompleteColum
 
 WORKER = '[bold cyan]TRAINER[/bold cyan]'
 
+
+_EVAL_FUNCTIONS = {
+    'f1': f1_score,
+    'precision': precision_score,
+    'recall': recall_score
+}
+
+
 class Trainer:
+    """
+    Trainer - can train pytorch model based on Dataset and Model passed in
+
+    Params:
+        device => torch.cuda.device: primary device to put model and data on
+    
+    """
+
+
     def __init__(self, 
-                 device
+                 device: torch.cuda.device
                  ):
         self.device = device
         logging.info(f'{WORKER}: Trainer initialized on {device}') 
 
-
-        
     def _get_loss_pred(self, outputs, labels, loss_fn, threshold, binary):
         """
         get loss and prediction from output of NN
@@ -89,7 +104,7 @@ class Trainer:
         output_str = ''
 
         for metric_name in metrics_list:
-            metric_func = metrics_list[metric_name]
+            metric_func = _EVAL_FUNCTIONS[metric_name]
 
             if metric_name == 'confusion_matrix':
                 score = metric_func(y_true, y_pred)
@@ -115,20 +130,31 @@ class Trainer:
               params,
               eval_config = {
                 "focused_indexes": None,
-                "save_metric": f1_score,
+                "save_metric": 'f1',
                 "multiclass_average": "weighted",
                 "eval_freq": 1,
-                "watch_list": {
-                    "F1": f1_score,
-                    "Precision": precision_score,
-                    "Recall": recall_score
-                }
+                "watch_list": ["f1", "precision", "recall"]
               },
               early_stopping = None,
                                 ):
+        """
+        function that trains the model
+
+        Params:
+            ModelModule => PytorchNlpModel Object
+            TrainDataModule => Dataset Object
+            ValDataModule =? Dataset Object
+            params => dict like
+            eval_config => dict like
+            early_stopping => int or None
+        
+        Returns
+            model => PytorchNlpModel
+            model_info => dict
+        """    
+    
         ## set up data 
         binary =TrainDataModule.binary
-        labels_to_indexes = TrainDataModule.labels_to_indexes
         indexes_to_labels = TrainDataModule.indexes_to_labels
         label_col = TrainDataModule.label_col
         threshold = 0
@@ -136,7 +162,7 @@ class Trainer:
         
         # unpack variables in config
         watch_list = eval_config['watch_list']
-        save_metric = eval_config['save_metric']
+        save_metric_func = _EVAL_FUNCTIONS[eval_config['save_metric']]
         multiclass_average = eval_config['multiclass_average']
         eval_freq = eval_config['eval_freq']
         best_val_score = 0
@@ -277,9 +303,11 @@ class Trainer:
 
                         if focused_indexes: # if focused_indexes are passed in (multiclass only)
                             eval_results_im = self._evaluate_by_metrics(val_trues, val_preds, watch_list, average = None)
-                            val_score_all = save_metric(val_trues, val_preds, average=None, zero_division=0)
+                            val_score_all = save_metric_func(val_trues, val_preds, average=None, zero_division=0)
                             
                             eval_results = {}
+
+                            
                             # Log Score by Focused Indexes
                             for index in focused_indexes:
                                 label_name = indexes_to_labels[index]
@@ -299,7 +327,8 @@ class Trainer:
                             val_score = np.mean(val_score_all[focused_indexes])
                         else: # if not focused index or binary
                             eval_results = self._evaluate_by_metrics(val_trues, val_preds, watch_list, average = average, log = STEP_INFO)
-                            val_score = save_metric(val_trues, val_preds, average = average)
+                        
+                            val_score = save_metric_func(val_trues, val_preds, average = average)
 
                         val_scores_list.append(val_score)          
                         val_loss = np.mean(val_losses) # getting average val loss
@@ -348,7 +377,7 @@ class Evaluator:
         self.ModelModule = ModelModule
         self.device = device
     
-    def eval_model_detailed(self, data_loader, device, binary = True):
+    def _eval_model_detailed(self, data_loader, device, binary = True):
         model =  self.ModelModule.model
         model.eval()
         print('generating detailed evaluation..')
@@ -394,7 +423,7 @@ class Evaluator:
     def predict_cohort(self, DataModule):
         tokenizer = self.ModelModule.tokenizer
         dataloader = DataModule.create_data_loader(tokenizer)
-        texts_l, preds_l, preds_probas_l, true_labels_l, preds_probas_all_l = self.eval_model_detailed(dataloader, 
+        texts_l, preds_l, preds_probas_l, true_labels_l, preds_probas_all_l = self._eval_model_detailed(dataloader, 
                                                                                                        self.device, 
                                                                                                        binary = DataModule.binary)
         
